@@ -1,6 +1,8 @@
 # __init__.py
 import shrinemaiden.transcript
 import shrinemaiden.transcript_class
+import shrinemaiden.train
+import shrinemaiden.utils
 
 # Version of the package
-__version__ = "0.1.7"
+__version__ = "0.2.0"
